@@ -1,21 +1,22 @@
-## Copied from phangorn file phyDat.R.  Edited for style only.
-FastTable <- function (dataset) {                                                                                 
+## Copied from phangorn file phyDat.R.  Edited for style and trivial efficiency gains
+FastTable <- function (dataset) {
   if(!is.data.frame(dataset)) {
-    dataset <- as.data.frame(dataset, stringsAsFactors = FALSE)                    
+    dataset <- as.data.frame(dataset, stringsAsFactors = FALSE)
   }
   da <- do.call("paste", c(dataset, sep = "\r"))
   ind <- !duplicated(da)
   levels <- da[ind]
   cat <- factor(da, levels = levels)
   nl <- length(levels(cat))
-  bin <- (as.integer(cat) - 1)                            
+  bin <- (as.integer(cat) - 1L)
   pd <- nl
   bin <- bin[!is.na(bin)]
-  if (length(bin)) bin <- bin + 1
+  if (length(bin)) bin <- bin + 1L
   y <- tabulate(bin, pd)
-  result <- list(index = bin, weights = y, dataset = dataset[ind,])
-  result                                                                              
-}   
+  
+  # Return:
+  list(index = bin, weights = y, dataset = dataset[ind, ])
+}
 
 #' Prepare data for Profile Parsimony
 #' 
@@ -45,7 +46,7 @@ PrepareDataProfile <- function (dataset, precision = 1e+06, warn = TRUE) {
   cont <- attr(dataset, "contrast")
   nTip <- length(dataset)
   
-  powers.of.2 <- 2L ^ c(0L:(nLevel - 1L))
+  powers.of.2 <- 2L ^ c(0L, seq_len(nLevel - 1L))
   tmp <- cont %*% powers.of.2
   tmp <- as.integer(tmp)
   unlisted <- unlist(dataset, recursive=FALSE, use.names=FALSE)
@@ -77,7 +78,7 @@ PrepareDataIW <- function (dataset) {
   cont <- attr(dataset, "contrast")
   nTip <- length(dataset)
   
-  powers.of.2 <- 2L ^ c(0L:(nLevel - 1L))
+  powers.of.2 <- 2L ^ c(0L, seq_len(nLevel - 1L))
   inappLevel <- which(at$levels == "-")
   cont[, inappLevel] <- 0
   tmp <- as.integer(cont %*% powers.of.2)
@@ -92,15 +93,47 @@ PrepareDataIW <- function (dataset) {
 
 #' Minimum steps
 #' 
-#' Smallest number of steps that a character can take on any tree
+#' The smallest number of steps that a character can take on any tree.
 #' 
-#' @param states Integer vector listing the tokens that may be present at each tip along a single character,
-#'               with each token represented as a binary digit; e.g. a value of 11 means that
-#'               the tip may have tokens 0, 1 or 3 (as 11 = 2^0 + 2^1 + 2^3).
-#'               As the minimum steps can be found when inapplicables occur together,
-#'               inapplicable tokens can be denoted as ?s or with the integer 0 (not 2^0).
+#' 
+#' @param states Integer vector listing the tokens that may be present at each 
+#' tip along a single character, with each token represented as a binary digit;
+#' e.g. a value of 11 means that
+#' the tip may have tokens 0, 1 or 3 (as 11 = 2^0 + 2^1 + 2^3).
+#' As the minimum steps can be found when inapplicables occur together,
+#' inapplicable tokens can be denoted as ?s or with the integer 0 (not 2^0).
+#' Tokens that are ambiguous for an inapplicable and an applicable
+#' state are not presently supported.
 #'               
-#' @return An integer specifying the minimum number of steps that the character must contain
+#' @return An integer specifying the minimum number of steps that the character
+#'  must contain.
+#'
+#' @examples {
+#'   data('inapplicable.datasets')
+#'   myPhyDat <- inapplicable.phyData[[4]] # or as.phyDat(read.nexus.data('filepath'))
+#'   class(myPhyDat) # phyDat object
+#'   
+#'   # Convert list of character codings to an array
+#'   myData <- vapply(myPhyDat, I, myPhyDat[[1]])
+#'   
+#'   # Convert phyDat's representation of states to binary
+#'   myContrast <- attr(myPhyDat, 'contrast')
+#'   tokens <- colnames(myContrast)
+#'   binaryContrast <- integer(length(tokens))
+#'   tokenApplicable <- tokens != '-'
+#'   binaryContrast[tokenApplicable] <- 2 ^ (seq_len(sum(tokenApplicable)) - 1)
+#'   binaryValues <- apply(myContrast, 1, 
+#'     function (row) sum(binaryContrast[as.logical(row)]))
+#'   myStates <- matrix(binaryValues[myData], nrow=nrow(myData),
+#'                      ncol=ncol(myData), dimnames=dimnames(myData))
+#'  
+#'   # Finally, work out minimum steps 
+#'   apply(myStates, 1, MinimumSteps)
+#'   
+#' }
+#'
+#' @author Martin R. Smith
+#' @export
 MinimumSteps <- function (states) {
   
   uniqueStates <- unique(states[states>0])
